jQuery bgiframe Visual Test

# jQuery bgiframe - Visual Test

##

nothing

top:
  'auto'
left:
  'auto'
width:
  'auto'
height:
  'auto'

top:
  0
left:
  0
width:
  'auto'
height:
  'auto'

top:
  -5
left:
  -5
width:
  270
height:
  120

top:
  0
left:
  0
width:
  260
height:
  110

top:
  '-5px'
left:
  '-5px'
width:
  '270px'
height:
  '120px'

top:
  '-.5em'
left:
  '-.5em'
width:
  '17em'
height:
  '12em'

top:
  '-.5em'
left:
  '-.5em'
width:
  'auto'
height:
  'auto'

top:
  'auto'
left:
  'auto'
width:
  'auto'
height:
  'auto'
opacity:
  false